=======================================
``psyclone.psyir.symbols.typed_symbol``
=======================================

.. automodule:: psyclone.psyir.symbols.typed_symbol

   .. contents::
      :local:

.. currentmodule:: psyclone.psyir.symbols.typed_symbol
